@@ -85,6 +85,15 @@ class KiloSortSession(object):
 		if os.path.exists(os.path.join(self.fname_root, 'cluster_group.tsv')):
 			self.cluster_id, self.group = np.loadtxt(os.path.join(self.fname_root, 'cluster_group.tsv'), unpack=True, skiprows=1, dtype=dtype)
 		
+		"""
+		Output some information to the user if self.cluster_id is still None
+		it implies that data has not been sorted / curated
+		"""
+		if self.cluster_id is None:
+			print(f"Searching {os.path.join(self.fname_root)} and...")
+			warnings.warn("No cluster_groups.tsv or cluster_group.csv file was found.\
+				Have you manually curated the data (e.g with phy?")
+
 		# HWPD 20200527 
 		# load cluster_info file and add X co-ordinate to it
 		if os.path.exists(os.path.join(self.fname_root, 'cluster_info.tsv')): # load cluster_info file and add X co-ordinate to it
@@ -95,22 +104,15 @@ class KiloSortSession(object):
 				chID = np.asarray([np.argmax(chMap==x) for x in self.cluster_info.ch.values])
 				self.cluster_info['chanX'] = chXZ[chID,0]
 				self.cluster_info['chanY'] = chXZ[chID,1]
-		"""
-		Output some information to the user if self.cluster_id is still None
-		it implies that data has not been sorted / curated
-		"""
-		if self.cluster_id is None:
-			warnings.warn("No cluster_groups.tsv or cluster_group.csv file was found.\
-				Have you manually curated the data (e.g with phy?")
 		
 		dtype = {'names': ('cluster_id', 'KSLabel'), 'formats': ('i4', 'S10')}
 		# 'Raw' labels from a kilosort session
 		if os.path.exists(os.path.join(self.fname_root, 'cluster_KSLabel.tsv')):
 			self.ks_cluster_id, self.ks_group = np.loadtxt(os.path.join(self.fname_root, 'cluster_KSLabel.tsv'), unpack=True, skiprows=1, dtype=dtype)
-		if self.spk_clusters is not None:
+		if os.path.exists(os.path.join(self.fname_root, 'spike_clusters.npy')):
 			self.spk_clusters = np.squeeze(np.load(os.path.join(self.fname_root, 'spike_clusters.npy')))
-		if self.spk_times is not None:
-			self.spk_times    = np.squeeze(np.load(os.path.join(self.fname_root, 'spike_times.npy')))
+		if os.path.exists(os.path.join(self.fname_root, 'spike_times.npy')):
+			self.spk_times = np.squeeze(np.load(os.path.join(self.fname_root, 'spike_times.npy')))
 			return True
 		warnings.warn("No spike times or clusters were found (spike_times.npy or spike_clusters.npy).\
 				You should run KiloSort")
@@ -181,7 +183,10 @@ class OpenEphysBase(object):
 		# Loads a kilosort session
 		kilodata = KiloSortSession(pname) # pname_root gets walked through and over-written with correct location of kiolsort data
 		if kilodata.load():
-			kilodata.removeKSNoiseClusters()
+			try:
+				kilodata.removeKSNoiseClusters()
+			except:
+				pass
 		self.kilodata = kilodata
 
 	def __loadSettings__(self):
